﻿using System;
using System.Threading.Tasks;
using Microsoft.Applications.Events;
using Microsoft.Dynamics.ProductInsights;

namespace PIAnalyticsSample
{
    class Program
    {
        static void Main(string[] args)
        {
            // Make sure to replace this with your ingestion key
            string ingestionKey = "{YOUR_INGESTION_KEY}";
            LogManager.Start(new LogConfiguration());
            ProductInsightsAnalytics analytics = new ProductInsightsAnalytics(ingestionKey);

            int signalCount = 0;
            bool stopLogging = false;

            Console.CancelKeyPress += delegate
            {
                stopLogging = true;
                Console.WriteLine("Ctrl+C detected, stop logging...");
            };

            Random random = new Random();
            Console.WriteLine("Start to send signals...");
            while(!stopLogging)
            {
                Asset asset = new Asset()
                {
                    AssetId = $"Asset{random.Next(10000)}",
                    DeviceId = $"Device{random.Next(10000)}",
                    SerialNumber = $"SC3141N{random.Next(10000)}"
                };

                Product product = new Product()
                {
                    ModelNumber = $"Model{random.Next(10000)}",
                    PartNumber = $"Part{random.Next(10000)}",
                    ProductId = Guid.NewGuid().ToString()
                };

                Signal signal = new Signal("car_information")
                {
                    Version = "1.0.0",
                    Asset = asset,
                    Product = product
                };
                signal.SetProperty("engine_start", true);
                signal.SetProperty("car_model", "Star Car");

                // This will generate a model_year between 2010 and 2019
                signal.SetProperty("model_year", random.Next(2010, 2019));

                // This will generate a random integer between 0 and 10000 for RPM
                signal.SetProperty("rpm", random.Next(10000));

                // This will generate a random number between 0 and 100 for temperature
                signal.SetProperty("temperature", random.NextDouble() * 100);

                analytics.TrackSignal(signal);

                Console.WriteLine($"Sending event: {signal.Name}");

                signalCount++;

                if (signalCount % 20 == 0)
                {
                    System.Threading.Thread.Sleep(1000);
                }
            }
            
            LogManager.UploadNow();
            LogManager.Teardown();
        }
    }
}
